# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.predictiveapp.v1 import predictiveapp_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2


class PredictiveAppServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPredictiveApps = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/ListPredictiveApps',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsResponse.FromString,
                )
        self.CreatePredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/CreatePredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppResponse.FromString,
                )
        self.GetPredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/GetPredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppResponse.FromString,
                )
        self.UpdatePredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/UpdatePredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppResponse.FromString,
                )
        self.DeletePredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/DeletePredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppResponse.FromString,
                )
        self.PausePredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/PausePredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppResponse.FromString,
                )
        self.ResumePredictiveApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/ResumePredictiveApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppResponse.FromString,
                )


class PredictiveAppServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPredictiveApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PausePredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumePredictiveApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PredictiveAppServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPredictiveApps': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPredictiveApps,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsResponse.SerializeToString,
            ),
            'CreatePredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppResponse.SerializeToString,
            ),
            'GetPredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppResponse.SerializeToString,
            ),
            'UpdatePredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppResponse.SerializeToString,
            ),
            'DeletePredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppResponse.SerializeToString,
            ),
            'PausePredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.PausePredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppResponse.SerializeToString,
            ),
            'ResumePredictiveApp': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumePredictiveApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PredictiveAppService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPredictiveApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/ListPredictiveApps',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ListPredictiveAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/CreatePredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.CreatePredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/GetPredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.GetPredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/UpdatePredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.UpdatePredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/DeletePredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.DeletePredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PausePredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/PausePredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.PausePredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumePredictiveApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService/ResumePredictiveApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictiveapp_dot_v1_dot_predictiveapp__pb2.ResumePredictiveAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto',
  package='github.com.metaprov.modelaapi.services.webrequestrun.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/webrequestrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto\x12\x37github.com.metaprov.modelaapi.services.webrequestrun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xdb\x01\n\x19ListWebRequestRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x1aListWebRequestRunsResponse\x12V\n\x05items\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunList\"\x1d\n\x1b\x43reateWebRequestRunResponse\"o\n\x1a\x43reateWebRequestRunRequest\x12Q\n\x04item\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"o\n\x1aUpdateWebRequestRunRequest\x12Q\n\x04item\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\x1d\n\x1bUpdateWebRequestRunResponse\":\n\x17GetWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x18GetWebRequestRunResponse\x12Q\n\x04item\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteWebRequestRunResponse2\x97\t\n\x14WebRequestRunService\x12\xd9\x01\n\x12ListWebRequestRuns\x12R.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest\x1aS.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/webeequestruns\x12\xdf\x01\n\x13\x43reateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/webeequestruns:\x01*\x12\xda\x01\n\x10GetWebRequestRun\x12P.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest\x1aQ.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/webeequestruns/{name}\x12\xfd\x01\n\x13UpdateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse\";\x82\xd3\xe4\x93\x02\x35\x1a\x30/v1/webeequestruns/{webeequestrun.metadata.name}:\x01*\x12\xe3\x01\n\x13\x44\x65leteWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/v1/webeequestruns/{name}B9Z7github.com/metaprov/modelaapi/services/webrequestrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=456,
)

_LISTWEBREQUESTRUNSREQUEST = _descriptor.Descriptor(
  name='ListWebRequestRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=456,
)


_LISTWEBREQUESTRUNSRESPONSE = _descriptor.Descriptor(
  name='ListWebRequestRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=574,
)


_CREATEWEBREQUESTRUNRESPONSE = _descriptor.Descriptor(
  name='CreateWebRequestRunResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=605,
)


_CREATEWEBREQUESTRUNREQUEST = _descriptor.Descriptor(
  name='CreateWebRequestRunRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=718,
)


_UPDATEWEBREQUESTRUNREQUEST = _descriptor.Descriptor(
  name='UpdateWebRequestRunRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=831,
)


_UPDATEWEBREQUESTRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateWebRequestRunResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=862,
)


_GETWEBREQUESTRUNREQUEST = _descriptor.Descriptor(
  name='GetWebRequestRunRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=922,
)


_GETWEBREQUESTRUNRESPONSE = _descriptor.Descriptor(
  name='GetWebRequestRunResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1047,
)


_DELETEWEBREQUESTRUNREQUEST = _descriptor.Descriptor(
  name='DeleteWebRequestRunRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1049,
  serialized_end=1110,
)


_DELETEWEBREQUESTRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteWebRequestRunResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1141,
)

_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY.containing_type = _LISTWEBREQUESTRUNSREQUEST
_LISTWEBREQUESTRUNSREQUEST.fields_by_name['labels'].message_type = _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY
_LISTWEBREQUESTRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTRUNLIST
_CREATEWEBREQUESTRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTRUN
_UPDATEWEBREQUESTRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTRUN
_GETWEBREQUESTRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTRUN
DESCRIPTOR.message_types_by_name['ListWebRequestRunsRequest'] = _LISTWEBREQUESTRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListWebRequestRunsResponse'] = _LISTWEBREQUESTRUNSRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestRunResponse'] = _CREATEWEBREQUESTRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestRunRequest'] = _CREATEWEBREQUESTRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestRunRequest'] = _UPDATEWEBREQUESTRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestRunResponse'] = _UPDATEWEBREQUESTRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetWebRequestRunRequest'] = _GETWEBREQUESTRUNREQUEST
DESCRIPTOR.message_types_by_name['GetWebRequestRunResponse'] = _GETWEBREQUESTRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWebRequestRunRequest'] = _DELETEWEBREQUESTRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteWebRequestRunResponse'] = _DELETEWEBREQUESTRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListWebRequestRunsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestRunsRequest)
_sym_db.RegisterMessage(ListWebRequestRunsRequest.LabelsEntry)

ListWebRequestRunsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestRunsResponse)

CreateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestRunResponse)

CreateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRunRequest)

UpdateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunRequest)

UpdateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunResponse)

GetWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRunRequest)

GetWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse)
  })
_sym_db.RegisterMessage(GetWebRequestRunResponse)

DeleteWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunRequest)

DeleteWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunResponse)


DESCRIPTOR._options = None
_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._options = None

_WEBREQUESTRUNSERVICE = _descriptor.ServiceDescriptor(
  name='WebRequestRunService',
  full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1144,
  serialized_end=2319,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListWebRequestRuns',
    full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService.ListWebRequestRuns',
    index=0,
    containing_service=None,
    input_type=_LISTWEBREQUESTRUNSREQUEST,
    output_type=_LISTWEBREQUESTRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/webeequestruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateWebRequestRun',
    full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService.CreateWebRequestRun',
    index=1,
    containing_service=None,
    input_type=_CREATEWEBREQUESTRUNREQUEST,
    output_type=_CREATEWEBREQUESTRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/webeequestruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWebRequestRun',
    full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService.GetWebRequestRun',
    index=2,
    containing_service=None,
    input_type=_GETWEBREQUESTRUNREQUEST,
    output_type=_GETWEBREQUESTRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1/webeequestruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateWebRequestRun',
    full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService.UpdateWebRequestRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEWEBREQUESTRUNREQUEST,
    output_type=_UPDATEWEBREQUESTRUNRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0320/v1/webeequestruns/{webeequestrun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWebRequestRun',
    full_name='github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService.DeleteWebRequestRun',
    index=4,
    containing_service=None,
    input_type=_DELETEWEBREQUESTRUNREQUEST,
    output_type=_DELETEWEBREQUESTRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\033*\031/v1/webeequestruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBREQUESTRUNSERVICE)

DESCRIPTOR.services_by_name['WebRequestRunService'] = _WEBREQUESTRUNSERVICE

# @@protoc_insertion_point(module_scope)
